@@ -1,2 +1,2 @@
 from pytiers.core import Point, PitchTier, DurationTier, parameters
-from pytiers.utils import read_Tier
\ No newline at end of file
+from pytiers.utils import read_tier
\ No newline at end of file
